// MTS GPSDataLogger
// SD Card using SPI, CS on pin 10
// using MTK33x9 chipset
//    ------> http://www.adafruit.com/products/746
// Pick one up today at the Adafruit electronics shop
// and help support open source hardware & software! -ada

#include <SPI.h>

#include <SdFat.h> // Use SdFat so can have .nmea extension
SdFat SD;

#include <Adafruit_GPS.h>

Adafruit_GPS GPS(&Serial1); // GPS connected to Featherwing Serial1

const int chipSelect = 10;	// Chip select for SD

// Set GPSECHO to 'false' to turn off echoing the GPS data to the Serial console
// Set to 'true' if you want to debug and listen to the raw GPS sentences
#define GPSECHO  false

unsigned long LogInterval=60000;	// milliseconds
unsigned long StartTime;	//Log Interval counter
File MISCFile;

void setup(){

	// connect at 115200 so we can read the GPS fast enough and echo without dropping chars
	// also spit it out
	if (GPSECHO){
		Serial.begin(115200);
		while (!Serial){
			; // wait for serial port to connect. Needed for native USB port only
		}
		Serial.print("Initializing SD card...");
  }
  
	// see if the card is present and can be initialized:
	if (!SD.begin(chipSelect)){
		Serial.println("Card failed, or not present");
		// don't do anything more:
		while (1);
	}
	if (GPSECHO)
		Serial.println("card initialized.");

	// 9600 NMEA is the default baud rate for Adafruit MTK GPS's- some use 4800
	GPS.begin(9600);

	// Setup the GPS

	// uncomment this line to turn on RMC (recommended minimum) and GGA (fix data) including altitude
	GPS.sendCommand(PMTK_SET_NMEA_OUTPUT_RMCGGA);
	//Turn off antenna update nuisance data
	GPS.sendCommand("$PGCMD,33,0*6D");  
	// Set the update rate
	GPS.sendCommand(PMTK_SET_NMEA_UPDATE_1HZ);   // 1 Hz update rate
	// For the parsing code to work nicely and have time to sort thru the data, and
	// print it out we don't suggest using anything higher than 1 Hz
  
	delay(1000);
   
	MISCFile = SD.open("Misc.txt", FILE_WRITE);
	MISCFile.println("Time, LatitudeDegrees, LongitudeDegrees, Altitude, Satellites, Speed, Angle, Fixquality, HDOP");
	MISCFile.close();

	 StartTime=millis(); //Initialize StartTime

}

void loop(){
	char c = GPS.read();
	// if you want to debug, this is a good time to do it!
	//  if ((c) && (GPSECHO))
	//    Serial.write(c);

	// if a sentence is received, we can check the checksum, parse it...
	if (GPS.newNMEAreceived()) {
		// a tricky thing here is if we print the NMEA sentence, or data
		// we end up not listening and catching other sentences!
		// so be very wary if using OUTPUT_ALLDATA and trytng to print out data
		if (GPS.parse(GPS.lastNMEA())){   // this also sets the newNMEAreceived() flag to false
			if (GPSECHO)
				Serial.println(GPS.lastNMEA());   // this also sets the newNMEAreceived() flag to false

			// open the file. note that only one file can be open at a time,
			// so you have to close this one before opening another.
			File NMEAFile = SD.open("Data.nmea", FILE_WRITE);

			// if the file is available, write to it:
			if (NMEAFile) {
				NMEAFile.println(GPS.lastNMEA());
				NMEAFile.close();
			}
		}
		// if the file isn't open, pop up an error:
		else {
			if (GPSECHO)
			Serial.println("error opening Data.nmea");
		}
	}
	if ((millis()-StartTime)>LogInterval){  // Log Interval has passed
		MISCFile = SD.open("Misc.txt", FILE_WRITE);
		if (GPS.hour < 6 )
			GPS.hour += 18;
		else
			GPS.hour -= 6;
		MISCFile.print(GPS.hour);	// Adjust to MST?
		MISCFile.print(':');
		MISCFile.print(GPS.minute);
		MISCFile.print(':');
		MISCFile.print(GPS.seconds);
		MISCFile.print(',');
		MISCFile.print(GPS.latitudeDegrees,7);
		MISCFile.print(',');
		MISCFile.print(GPS.longitudeDegrees,7);
		MISCFile.print(',');
		MISCFile.print(GPS.altitude * 3.28,1);	// to feet
		MISCFile.print(',');
		MISCFile.print(GPS.satellites,1);
		MISCFile.print(',');
		MISCFile.print(GPS.speed * 1.15,3);	// to mph
		MISCFile.print(',');
		MISCFile.print(GPS.angle,2);
		MISCFile.print(',');
		MISCFile.print(GPS.fixquality);
		MISCFile.print(',');
		MISCFile.println(GPS.HDOP,2);
		MISCFile.close();
		StartTime = millis();	//Get StartTime for next LogInterval
	}
}
